==> org.jresearch.commons.gwt.app-1.0.169.jar: org/jresearch/commons/gwt/app/client/UserHolder.java <==
package org.jresearch.commons.gwt.app.client;

import java.util.Optional;

import javax.annotation.Nonnull;

import org.fusesource.restygwt.client.Method;
import org.fusesource.restygwt.client.REST;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLoginEvent;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLoginHandler;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLogoutEvent;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLogoutHandler;
import org.jresearch.commons.gwt.app.client.mvc.event.ProfileUpdateEvent;
import org.jresearch.commons.gwt.app.client.service.UserRestService;
import org.jresearch.commons.gwt.app.shared.model.user.UserModel;
import org.jresearch.commons.gwt.client.mvc.AbstractMethodCallback;
import org.jresearch.commons.gwt.client.mvc.event.Bus;
import org.jresearch.commons.gwt.shared.service.AnonymousUserRestException;

import com.google.inject.Inject;
import com.google.inject.Singleton;

/**
 * Holds the current user information.
 */
@Singleton
public class UserHolder implements AfterLogoutHandler, AfterLoginHandler {

	@Nonnull
	private final Bus bus;
	@Nonnull
	private final UserRestService userService;

	private String userId;
	private UserModel user;

	@Inject
	public UserHolder(@Nonnull final UserRestService userService, @Nonnull final Bus bus) {
		this.userService = userService;
		this.bus = bus;

		bus.addHandler(AfterLoginEvent.TYPE, this);
		bus.addHandler(AfterLogoutEvent.TYPE, this);

		updateUser();
	}

	private void updateUser() {
		REST.withCallback(new AbstractMethodCallback<UserModel>(bus) {
			@Override
			public void onSuccess(final Method method, final UserModel response) {
				setUser(response);
			}

			@Override
			public void onFailure(final Method method, final Throwable caught) {
				if (caught instanceof AnonymousUserRestException) {
					unsetUser();
				} else {
					super.onFailure(method, caught);
				}
			}
		}).call(userService).getCurrentUser();
	}

	@Nonnull
	public Optional<String> getCurrentUserId() {
		return Optional.ofNullable(userId);
	}

	@Nonnull
	public Optional<UserModel> getCurrentUser() {
		return Optional.ofNullable(user);
	}

	public void setUserId(final String userId) {
		this.userId = userId;
	}

	public void setUser(final UserModel user) {
		setUserId(user.getId().toString());
		this.user = user;
		bus.fire(new ProfileUpdateEvent(user.getUserProfile()));
	}

	public void unsetUserId() {
		userId = null;
	}

	public void unsetUser() {
		unsetUserId();
		user = null;
		bus.fire(new ProfileUpdateEvent(null));
	}

	@Override
	public void onAfterLogin(final AfterLoginEvent event) {
		final String newUserId = event.getUserId();
		if (!newUserId.equals(userId)) {
			unsetUser();
			setUserId(newUserId);
		}
		if (!getCurrentUser().isPresent()) {
			updateUser();
		}
	}

	@Override
	public void onAfterLogout(final AfterLogoutEvent afterLogoutEvent) {
		unsetUser();
	}

}

==> org.jresearch.commons.gwt.app-1.0.184.jar: org/jresearch/commons/gwt/app/client/UserHolder.java <==
package org.jresearch.commons.gwt.app.client;

import java.util.Optional;

import javax.annotation.Nonnull;

import org.fusesource.restygwt.client.Method;
import org.fusesource.restygwt.client.REST;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLoginEvent;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLoginHandler;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLogoutEvent;
import org.jresearch.commons.gwt.app.client.mvc.event.AfterLogoutHandler;
import org.jresearch.commons.gwt.app.client.mvc.event.ProfileUpdateEvent;
import org.jresearch.commons.gwt.app.client.service.UserRestService;
import org.jresearch.commons.gwt.app.shared.model.user.UserModel;
import org.jresearch.commons.gwt.client.mvc.AbstractMethodCallback;
import org.jresearch.commons.gwt.client.mvc.event.Bus;
import org.jresearch.commons.gwt.client.tool.GwtDeferredTask;
import org.jresearch.commons.gwt.shared.service.AnonymousUserRestException;

import com.google.inject.Inject;
import com.google.inject.Singleton;

/**
 * Holds the current user information.
 */
@Singleton
public class UserHolder implements AfterLogoutHandler, AfterLoginHandler {

	@Nonnull
	private final Bus bus;
	@Nonnull
	private final UserRestService userService;

	private String userId;
	private UserModel user;

	@Inject
	public UserHolder(@Nonnull final UserRestService userService, @Nonnull final Bus bus) {
		this.userService = userService;
		this.bus = bus;

		bus.addHandler(AfterLoginEvent.TYPE, this);
		bus.addHandler(AfterLogoutEvent.TYPE, this);

		new GwtDeferredTask(this::updateUser).defer(1);
		// updateUser();
	}

	private void updateUser() {
		REST.withCallback(new AbstractMethodCallback<UserModel>(bus) {
			@Override
			public void onSuccess(final Method method, final UserModel response) {
				setUser(response);
			}

			@Override
			public void onFailure(final Method method, final Throwable caught) {
				if (caught instanceof AnonymousUserRestException) {
					unsetUser();
				} else {
					super.onFailure(method, caught);
				}
			}
		}).call(userService).getCurrentUser();
	}

	@Nonnull
	public Optional<String> getCurrentUserId() {
		return Optional.ofNullable(userId);
	}

	@Nonnull
	public Optional<UserModel> getCurrentUser() {
		return Optional.ofNullable(user);
	}

	public void setUserId(final String userId) {
		this.userId = userId;
	}

	public void setUser(final UserModel user) {
		setUserId(user.getId().toString());
		this.user = user;
		bus.fire(new ProfileUpdateEvent(user.getUserProfile()));
	}

	public void unsetUserId() {
		userId = null;
	}

	public void unsetUser() {
		unsetUserId();
		user = null;
		bus.fire(new ProfileUpdateEvent(null));
	}

	@Override
	public void onAfterLogin(final AfterLoginEvent event) {
		final String newUserId = event.getUserId();
		if (!newUserId.equals(userId)) {
			unsetUser();
			setUserId(newUserId);
		}
		if (!getCurrentUser().isPresent()) {
			updateUser();
		}
	}

	@Override
	public void onAfterLogout(final AfterLogoutEvent afterLogoutEvent) {
		unsetUser();
	}

}
